-------------------------------------------------------------------------------
-- MrTrader 0.3
--
-- Lightweight addon to access profession information of alts.
--
-- Send suggestions, comments, and bugs to user@zedonline.net
-------------------------------------------------------------------------------

local L = LibStub("AceLocale-3.0"):GetLocale("MrTrader", true);

local Defaults = {
	realm = {
		skills = {},
	}
}

-- List of tradeskills
-- Key: Spell ID
-- Value: true if this skill has a tradeskill link you can share
local TradeSkills = {
	[2259] = true, -- Alchemy
	[2018] = true, -- Blacksmithing
	[2550] = true, -- Cooking
	[7411] = true, -- Enchanting
	[4036] = true, -- Engineering
	[3273] = true, -- First Aid
	[45357] = true, -- Inscription
	[25229] = true, -- Jewelcrafting
	[2108] = true, -- Leatherworking
	[53428] = false, -- Runeforging
	[2656] = false, -- Smelting
	[3908] = true, -- Tailoring
}

function MrTrader:Load()
	self.db = LibStub("AceDB-3.0"):New("MrTraderDB", Defaults, "Default");

	-- Convert from v0.1 to v0.3 DBs
	if self.db.factionrealm.skills then
		if self.db.realm.skills then
			self.db.realm.skills = self:TableJoin(self.db.realm.skills, self.db.factionrealm.skills);
		else
			self.db.realm.skills = self.db.factionrealm.skills;
		end

		self.db.factionrealm.skills = nil;

		for name, skillTable in pairs(self.db.realm.skills) do
			skillTable["faction"] = UnitFactionGroup("player");
			self.db.realm.skills[name] = skillTable;
		end
	end

	-- Set a DB version for easier upgrading post v0.3
	if self.db.global.version == nil then
		self.db.global.version = 2;
	end
end

function MrTrader:QuerySkills()
	local currentPlayer = UnitName("player");
	local currentFaction = UnitFactionGroup("player");	
	local skillTable = {};
	local oldTable = {};
	local didGrabUpdate = true;
	
	if self.db.realm.skills[currentPlayer] then
		oldTable = self.db.realm.skills[currentPlayer];
	end

	for skillID, usesLink in pairs(TradeSkills) do
		skillName = GetSpellInfo(skillID);
		doesExist, tradeLink = GetSpellLink(skillName);
		
		if doesExist and tradeLink then
			skillTable[skillID] = tradeLink;
		elseif doesExist and oldTable[skillID] then
			skillTable[skillID] = oldTable[skillID];
			didGrabUpdate = false;
		elseif doesExist then
			skillTable[skillID] = false;
			if usesLink then
				didGrabUpdate = false;
			end
		end
	end
	
	if self:TableSize(skillTable) > 0 then
		-- Saving the new table, copy over values that we want to keep
		skillTable["ignored"] = oldTable["ignored"];
		skillTable["faction"] = currentFaction;	

		self.db.realm.skills[currentPlayer] = skillTable;
		return didGrabUpdate;
	else
		self.db.realm.skills[currentPlayer] = nil;
		return true;
	end
end

function MrTrader:GetSkillTable()
	return self.db.realm.skills;
end

function MrTrader:RemoveCharacter(name)
	self.db.realm.skills[name] = nil;
end

function MrTrader:IgnoreCharacter(name)
	self.db.realm.skills[name]["ignored"] = true;
end

function MrTrader:UnignoreCharacter(name)
	self.db.realm.skills[name]["ignored"] = nil;
end

function MrTrader:PlayerIsIgnored(name)
	return self.db.realm.skills[name]["ignored"];
end