-------------------------------------------------------------------------------
-- MrTrader 0.3
--
-- Lightweight addon to access profession information of alts.
--
-- Send suggestions, comments, and bugs to user@zedonline.net
-------------------------------------------------------------------------------

local Menu = LibStub("Dewdrop-2.0");
local L = LibStub("AceLocale-3.0"):GetLocale("MrTrader");

function MrTrader:InitializeMenu()
	local LDB = LibStub("LibDataBroker-1.1", true);
	if LDB then
		self.launcherobj = LDB:NewDataObject("MrTrader", {
	    	type = "launcher",
			label = "MrTrader",
	    	icon = "Interface\\Addons\\MrTrader\\MrTrader",
	    	OnClick = function(clickedframe, button)
	        	MrTrader:OpenMenu(clickedframe, button);
	    	end,
			OnTooltipShow = function(tip)
				if not tip or not tip.AddLine then return end
				tip:AddLine("MrTrader")
				tip:AddLine(L["Click to open menu."], 1, 1, 1)
			end,
		})
	end
end

function MrTrader:OpenMenu(frame, button)
	if button == "LeftButton" then
		Menu:Open(frame, "children", function() MrTrader:UpdateMenu() end);
	end
end

function MrTrader:UpdateMenu()
	MrTrader:QuerySkills();
	skillTable = MrTrader:GetSkillTable();
	currentPlayer = UnitName("player");
	currentFaction = UnitFactionGroup("player");
	
	local spacer = {
		text = "",
		isTitle = true,
	}
	
	menu = {};
	local index = 100;
	local characterCount = MrTrader:TableSize(skillTable);
	
	if skillTable[currentPlayer] then
		characterCount = characterCount - 1;
	
		menu[index] = {
			text = L["Tradeskills"],
			textR = 1.0,
			textG = 0.8,
			textB = 0,
			isTitle = true,
		}
		index = index + 1;
		
		for skillID, skillLink in pairs(skillTable[currentPlayer]) do
			local skillName, _, skillIcon = GetSpellInfo(skillID);
			if skillName then
				menu[index] = {
					text = skillName,
					icon = skillIcon,
					iconHeight = 12,
					iconWidth = 12,
					closeWhenClicked = true,
					func = function()
						MrTrader:OpenLink(skillName, skillLink, true);
					end,
				}
				index = index + 1;
			end
		end
		
		menu[index] = spacer;
		index = index + 1;

		if MrTrader:PlayerIsIgnored(currentPlayer) then
			menu[index] = {
				text = L["Unignore"],
				tooltipTitle = L["Unignore"],
				tooltipText = L["Unignore this character and show on all other characters."],
				closeWhenClicked = true,
				func = function()
					MrTrader:UnignorePlayer(currentPlayer);
				end,
			}
			index = index + 1;			

			menu[index] = spacer;
			index = index + 1;		
		end
	end
	
	if characterCount > 0 then
		menu[index] = {
			text = L["Characters"],
			textR = 1.0,
			textG = 0.8,
			textB = 0,
			isTitle = true,
		}
		index = index + 1;
	
		for playerName, skillList in pairs(skillTable) do
			if playerName ~= currentPlayer and MrTrader:PlayerIsIgnored(playerName) ~= true then
				if skillList["faction"] and skillList["faction"] ~= currentFaction then
					menu[index] = {
						text = playerName,
						textR = 1.0,
						textG = 0.2,
						textB = 0.2,
						hasArrow = true,
					}			
				else
					menu[index] = {
						text = playerName,
						hasArrow = true,
					}
				end
				menu[index].subMenu = {};
				local subMenuIndex = 100;
				
				for skillID, skillLink in pairs(skillTable[playerName]) do
					local skillName, _, skillIcon = GetSpellInfo(skillID);

					if skillName then
						menu[index].subMenu[subMenuIndex] = {
							text = skillName,
							icon = skillIcon,
							iconHeight = 12,
							iconWidth = 12,
							closeWhenClicked = skillLink,
							disabled = not skillLink,
							func = function()
								MrTrader:OpenLink(skillName, skillLink, false);
							end,
						}
						subMenuIndex = subMenuIndex + 1;
					end
				end

				menu[index].subMenu[subMenuIndex] = spacer;
				subMenuIndex = subMenuIndex + 1;

				menu[index].subMenu[subMenuIndex] = {
					text = L["Remove"],
					tooltipTitle = L["Remove"],
					tooltipText = L["Click to remove from the list, shift-click to ignore this character permanently."],
					closeWhenClicked = true,
					func = function()
						if IsShiftKeyDown() then
							MrTrader:IgnoreCharacter(playerName);
						else
							MrTrader:RemoveCharacter(playerName);
						end
					end,
				}
				subMenuIndex = subMenuIndex + 1;
				
				index = index + 1;
			end
		end
		
		menu[index] = spacer;
		index = index + 1;
	end
	
	menu[index] = {
		text = L["Close"],
		closeWhenClicked = true,
	}
	
	Menu:FeedTable(menu);
end

function MrTrader:OpenLink(name, link, isCurrentPlayer)
	if IsModifiedClick() then
		-- Let the normal mechanisms handle the modified click on the link
		HandleModifiedItemClick(link);	
	else
		if isCurrentPlayer then
			CastSpellByName(name);
		else
			-- Open link via chat window
			local chatLink = string.gsub(link, "|", ":");
			local _, startIndex = string.find(chatLink, ":H");
			local endIndex = string.find(chatLink, ":h");
			chatLink = string.sub(chatLink, startIndex + 1, endIndex - 1);
			ChatFrame_OnHyperlinkShow(nil, chatLink, link, "LeftButton");
		end
	end
end